@@ -738,11 +738,7 @@ Script::Name *BayonneSession::attachStart(Event *event)
 
 	if(sla[0])
 	{
-		snprintf(buf, sizeof(buf), "%s::%s", sla, getExternal("session.interface"));
-		scr = img->getScript(buf);
-		if(scr)
-			goto final;
-		scr = img->getScript(sla);
+		scr = BayonneBinder::getService(img, this, sla);
 		if(scr)	
 			goto final;
 	}
@@ -860,13 +856,7 @@ incoming:
         }
 
 	if(!scr)
-	{
-		snprintf(buf, sizeof(buf), "down::%s", driver->getName());
-		scr = img->getScript(buf);
-		if(scr)
-			goto final;
-		scr = img->getScript("down");
-	}
+		scr = BayonneBinder::getService(img, this, NULL);
 
 final:
 	event->start.scr = scr;
