@@ -31,7 +31,7 @@ Service Service::tcp;
 bool Service::active = false;
 
 Service::Service() :
-BayonneService(-1, 0), Keydata(KEYS)
+BayonneService(-1, 0), Keydata(Bayonne::getKeypath(KEYS))
 {
 	static Keydata::Define defkeys[] = {
 	{"interface", "127.0.0.1"},
