@@ -115,22 +115,6 @@ const char *Checks::chkPaths(Line *line, ScriptImage *img)
 	return NULL;
 }
 
-const char *Checks::chkDial(Line *line, ScriptImage *img)
-{
-	unsigned idx = 0;
-
-	if(getMember(line))
-		return "dial uses no members";
-
-	if(!useKeywords(line, "=timeout"))
-		return "unknown keyword for dial";
-
-	if(!getOption(line, &idx))
-		return "dialed number argument missing";
-
-	return NULL;
-}
-
 const char *Checks::chkChildSignal(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
