@@ -421,7 +421,6 @@ void liveConfig(void)
 	Script::exec_extensions = SCRIPT_EXTENSIONS;
 #endif
 	Script::exec_token = "bayonne:";
-	Script::exec_prefix = "exec";
 
         Bayonne::allocate(timeslots, dynamic_cast<ScriptCommand *>(&runtime)); 
 }
@@ -601,9 +600,9 @@ retry:
 		goto retry;
 	} 
 
-        if(!strnicmp(option, "-binding=", 9))
+        if(!strnicmp(option, "-bind=", 6))
         {
-                keyserver.setValue("binding", option + 9);    
+                keyserver.setValue("binding", option + 6);    
                 ++argv;
                 goto retry;
         }  
@@ -824,7 +823,7 @@ retry:
                 goto retry;
         }
 
-        if(!stricmp(option, "-binding"))
+        if(!stricmp(option, "-bind"))
         {
                 ++argv;    
                 if(!*argv)
@@ -873,6 +872,9 @@ retry:
 	}
 #endif
 
+	cerr << "bayonne: " << *argv << ": unknown option" << endl;
+	exit(-1);
+
 skip:
 	while(*argv)
 	{
