@@ -22,24 +22,6 @@ namespace server {
 using namespace ost;
 using namespace std;
 
-bool Methods::scrDial(void)
-{
-	unsigned len = 0;
-	const char *cp;
-	
-	state.join.answer_timer = state.timeout = getTimeoutKeyword("timeout");
-	
-	while(NULL != (cp = getValue(NULL)))
-	{
-		snprintf(state.join.digits + len, sizeof(state.join.digits) - len, "%s", cp);
-		len = strlen(state.join.digits);
-	}
-
-	state.join.dial = state.join.digits;
-	setState(STATE_DIAL);
-	return false;
-}
-
 bool Methods::scrTransfer(void)
 {
 	char nbuf[MAX_PATHNAME];
