@@ -29,8 +29,6 @@ ScriptRuntime()
 	static ScriptInterp::Define interp[] = {
 		{"config", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkConfig},
-		{"dial", false, (Method)&Methods::scrDial,
-			(Check)&Checks::chkDial},
 		{"dialtone", false, (Method)&Methods::scrTone,
 			(Check)&Checks::chkTone},
                 {"busytone", false, (Method)&Methods::scrTone,
