@@ -196,7 +196,6 @@ public:
 	bool scrDTMF(void);
 	bool scrMF(void);
 	bool scrTransfer(void);
-	bool scrDial(void);
 };
 
 class Checks : public ScriptChecks, public Bayonne
@@ -225,10 +224,9 @@ public:
 	const char *chkLoad(Line *line, ScriptImage *img);
 	const char *chkBuild(Line *line, ScriptImage *img);
 	const char *chkTone(Line *line, ScriptImage *img);
-	const char *chkDialer(Line *line, ScriptImage *img);
 	const char *chkTransfer(Line *line, ScriptImage *img);
 	const char *chkChildSignal(Line *line, ScriptImage *img);
-	const char *chkDial(Line *line, ScriptImage *img);
+	const char *chkDialer(Line *line, ScriptImage *img);
 };
 
 extern Runtime runtime;
